IcedBackend

Struct IcedBackend 

pub struct IcedBackend { /* private fields */ }
👎Deprecated since 0.2.7: Use DampenWidgetBuilder instead. See migration guide in docs/MIGRATION.md
Iced backend implementation

DEPRECATED: This backend is deprecated and will be removed in v0.3.0.

Use DampenWidgetBuilder instead, which provides:

  • XML-based UI definitions
  • State-aware styling with hover/focus/active states
  • Handler parameter binding with context resolution
  • Hot-reload support during development

Migration

ⓘ
// Old (deprecated):
let backend = IcedBackend::new(|name, param| {
    Message::Handler(name, param)
});

// New (recommended):
let builder = DampenWidgetBuilder::from_document(&document)
    .with_handler_registry(handlers);

Implementations

Source

impl IcedBackend

pub fn new<F>(handler: F) -> Self
where F: Fn(String, Option<String>) -> Box<dyn CloneableMessage> + 'static,

Create a new Iced backend with a message handler